@@ -33,6 +33,7 @@
 #endif
 
 #include <errno.h>
+#include <stdlib.h>
 #include <string.h>
 
 #include <gio/gio.h>
@@ -110,36 +111,6 @@ na_core_utils_str_collate( const gchar *str1, const gchar *str2 )
 	return( res );
 }
 
-/**
- * na_core_utils_str_get_first_word:
- * @string: a space-separated string.
- *
- * Returns: the first word of @string, as a newly allocated string which
- * should be g_free() by the caller.
- */
-gchar *
-na_core_utils_str_get_first_word( const gchar *string )
-{
-	gchar **splitted, **iter;
-	gchar *word, *tmp;
-
-	splitted = g_strsplit( string, " ", 0 );
-	iter = splitted;
-	word = NULL;
-
-	while( *iter ){
-		tmp = g_strstrip( *iter );
-		if( g_utf8_strlen( tmp, -1 )){
-			word = g_strdup( tmp );
-			break;
-		}
-		iter++;
-	}
-
-	g_strfreev( splitted );
-	return( word );
-}
-
 /**
  * na_core_utils_str_remove_char:
  * @string: source string.
@@ -208,6 +179,46 @@ na_core_utils_str_remove_suffix( const gchar *string, const gchar *suffix )
 	return( removed );
 }
 
+/**
+ * na_core_utils_str_split_first_word:
+ * @string: a space-separated string.
+ * @first: a pointer to a gchar *.
+ * @other: a pointer to a gchar *.
+ *
+ * Split the @string string into two components:
+ * - the first word which is allocated in @first,
+ * - the rest of the string which is allocated in @other.
+ *
+ * The two allocated strings should be g_free() by the caller.
+ */
+void
+na_core_utils_str_split_first_word( const gchar *string, gchar **first, gchar **other )
+{
+	gchar **splitted, **iter;
+
+	splitted = g_strsplit( string, " ", 2 );
+	iter = splitted;
+
+	*first = g_strdup( *iter );
+	iter++;
+	*other = g_strdup( *iter );
+
+	g_strfreev( splitted );
+}
+
+void
+na_core_utils_slist_add_message( GSList **messages, const gchar *format, ... )
+{
+	va_list va;
+	gchar *tmp;
+
+	va_start( va, format );
+	tmp = g_markup_vprintf_escaped( format, va );
+	va_end( va );
+
+	*messages = g_slist_append( *messages, tmp );
+}
+
 /**
  * na_core_utils_slist_duplicate:
  * @source_slist: the #GSList to be duplicated.
@@ -234,21 +245,25 @@ na_core_utils_slist_duplicate( GSList *source_slist )
 
 /**
  * na_core_utils_slist_dump:
+ * @prefix: a string to be used as a prefix for each outputed line.
  * @list: a list of strings.
  *
  * Dumps the content of a list of strings.
  */
 void
-na_core_utils_slist_dump( GSList *list )
+na_core_utils_slist_dump( const gchar *prefix, GSList *list )
 {
 	static const gchar *thisfn = "na_core_utils_slist_dump";
 	GSList *i;
 	int c;
+	const gchar *thispfx;
 
-	g_debug( "%s: list at %p has %d element(s)", thisfn, ( void * ) list, g_slist_length( list ));
+	thispfx = ( prefix && strlen( prefix )) ? prefix : thisfn;
+
+	g_debug( "%s: list at %p has %d element(s)", thispfx, ( void * ) list, g_slist_length( list ));
 
 	for( i=list, c=0 ; i ; i=i->next ){
-		g_debug( "%s: [%2d] %s", thisfn, c++, ( gchar * ) i->data );
+		g_debug( "%s: [%2d] %s", thispfx, c++, ( gchar * ) i->data );
 	}
 }
 
@@ -327,7 +342,10 @@ na_core_utils_slist_join_at_end( GSList *slist, const gchar *link )
 	str = g_string_new( "" );
 
 	for( is = slist ; is ; is = is->next ){
-		g_string_append_printf( str, "%s%s", ( const gchar * ) is->data, link );
+		if( str->len ){
+			g_string_append_printf( str, "%s", link );
+		}
+		g_string_append_printf( str, "%s", ( const gchar * ) is->data );
 	}
 
 	return( g_string_free( str, FALSE ));
@@ -443,23 +461,87 @@ na_core_utils_slist_to_text( GSList *strlist )
 }
 
 /**
- * na_core_utils_slist_find:
+ * na_core_utils_slist_setup_element:
+ * @list: the GSList of strings to be setup.
+ * @element: the string to add to or remove of the list.
+ * @set: whether the @element should be set or removed.
+ *
+ * Setup the @list so that the @element is once in the @list if @set is %TRUE,
+ * or not if @set is %FALSE.
+ *
+ * Returns: the updated @list.
+ */
+GSList *
+na_core_utils_slist_setup_element( GSList *list, const gchar *element, gboolean set )
+{
+	guint count;
+
+	count = na_core_utils_slist_count( list, element );
+
+	if( set && count == 0 ){
+		list = g_slist_prepend( list, g_strdup( element ));
+	}
+	if( !set && count > 0 ){
+		list = na_core_utils_slist_remove_ascii( list, element );
+	}
+
+	return( list );
+}
+
+/**
+ * na_core_utils_slist_count:
  * @list: the GSList of strings to be searched.
  * @str: the searched string.
  *
  * Search for a string in a string list.
  *
- * Returns: %TRUE if the string has been found in list.
+ * Returns: the count of @ßtr in @list list.
  */
-gboolean
-na_core_utils_slist_find( GSList *list, const gchar *str )
+guint
+na_core_utils_slist_count( GSList *list, const gchar *str )
 {
+	guint count;
 	GSList *il;
 
+	count = 0;
+
 	for( il = list ; il ; il = il->next ){
 		const gchar *istr = ( const gchar * ) il->data;
 		if( !na_core_utils_str_collate( str, istr )){
-			return( TRUE );
+			count += 1;
+		}
+	}
+
+	return( count );
+}
+
+/**
+ * na_core_utils_slist_find_negated:
+ * @list: the GSList of strings to be searched.
+ * @str: the searched string.
+ *
+ * Search for a string in a string list which may contain nagated items.
+ *
+ * Returns: %TRUE if the string has been found in list.
+ */
+gboolean
+na_core_utils_slist_find_negated( GSList *list, const gchar *str )
+{
+	GSList *il;
+
+	for( il = list ; il ; il = il->next ){
+		const gchar *istr = g_strstrip( g_strdup( ( const gchar * ) il->data ));
+
+		if( istr[0] == '!' ){
+			gchar *istrdup = g_strdup( istr+1 );
+			int match = na_core_utils_str_collate( str, istrdup );
+			g_free( istrdup );
+			if( match == 0 ){
+				return( TRUE );
+			}
+
+		} else if( na_core_utils_str_collate( str, istr ) == 0 ){
+				return( TRUE );
 		}
 	}
 
@@ -482,14 +564,14 @@ na_core_utils_slist_are_equal( GSList *first, GSList *second )
 
 	for( il = first ; il ; il = il->next ){
 		const gchar *str = ( const gchar * ) il->data;
-		if( !na_core_utils_slist_find( second, str )){
+		if( na_core_utils_slist_count( second, str ) == 0 ){
 			return( FALSE );
 		}
 	}
 
 	for( il = second ; il ; il = il->next ){
 		const gchar *str = ( const gchar * ) il->data;
-		if( !na_core_utils_slist_find( first, str )){
+		if( na_core_utils_slist_count( first, str ) == 0 ){
 			return( FALSE );
 		}
 	}
@@ -571,6 +653,42 @@ text_to_string_list( const gchar *text, const gchar *separator, const gchar *def
 	return( strlist );
 }
 
+/***
+ * na_core_utils_selcount_get_ope:
+ * @selcount: the selection count condition string.
+ * @ope: a pointer to a newly allocated string which will contains the
+ *  operation code.
+ * @uint: a pointer to a newly allocated string which will contains the
+ *  relevant integer.
+ *
+ * Parses a selection count string, and extract the operation code and the
+ * relevant integer.
+ *
+ * The two returned strings must be g_free() by the caller.
+ */
+void
+na_core_utils_selcount_get_ope_int( const gchar *selcount, gchar **ope, gchar **uint )
+{
+	gchar *dup, *dup2;
+	guint uint_int;
+
+	g_return_if_fail( ope && uint );
+
+	*ope = NULL;
+	*uint = NULL;
+
+	dup = g_strstrip( g_strdup( selcount ));
+	*ope = g_strdup( " " );
+	*ope[0] = dup[0];
+
+	dup2 = g_strstrip( g_strdup( dup+1 ));
+	uint_int = abs( atoi( dup2 ));
+	*uint = g_strdup_printf( "%d", uint_int );
+
+	g_free( dup2 );
+	g_free( dup );
+}
+
 /**
  * na_core_utils_dir_is_writable_path:
  * @path: the path of the directory to be tested.
@@ -671,6 +789,48 @@ info_dir_is_writable( GFile *file, const gchar *path_or_uri )
 	return( writable );
 }
 
+/**
+ * na_core_utils_dir_split_ext:
+ * @string: the input path or URI to be splitted.
+ * @first: a pointer to a buffer which will contain the first part of the split.
+ * @ext: a pointer to a buffer which will contain the extension part of the path.
+ *
+ * Split the given @string, returning the first part and the extension in newly
+ * allocated buffers which should be g_free() by the caller.
+ *
+ * Returns an empty string as extension if no extension is detected.
+ */
+void
+na_core_utils_dir_split_ext( const gchar *string, gchar **first, gchar **ext )
+{
+	gchar *dupped;
+	gchar **array, **iter;
+
+	dupped = g_strreverse( g_strdup( string ));
+	array = g_strsplit( dupped, ".", 2 );
+
+	if( g_strv_length( array ) == 1 ){
+		if( ext ){
+			*ext = g_strdup( "" );
+		}
+		if( first ){
+			*first = g_strreverse( g_strdup(( const gchar * ) *array ));
+		}
+	} else {
+		if( ext ){
+			*ext = g_strreverse( g_strdup(( const gchar * ) *array ));
+		}
+		iter = array;
+		++iter;
+		if( first ){
+			*first = g_strreverse( g_strdup(( const gchar * ) *iter ));
+		}
+	}
+
+	g_strfreev( array );
+	g_free( dupped );
+}
+
 /**
  * na_core_utils_file_delete:
  * @path: the path of the file to be deleted.
@@ -718,6 +878,38 @@ na_core_utils_file_exists( const gchar *fname )
 	return( exists );
 }
 
+/**
+ * na_core_utils_file_load_from_uri:
+ * @uri: the URI the file must be loaded from.
+ * @length: a pointer to the length of the readen content.
+ *
+ * Loads the file into a newly allocated buffer, and set up the length of the
+ * readen content if not %NULL.
+ *
+ * Returns: the newly allocated buffer which contains the file content, or %NULL.
+ * This buffer should be g_free() by the caller.
+ */
+gchar *
+na_core_utils_file_load_from_uri( const gchar *uri, gsize *length )
+{
+	gchar *data;
+	GFile *file;
+
+	file = g_file_new_for_uri( uri );
+
+	if( !g_file_load_contents( file, NULL, &data, length, NULL, NULL )){
+		g_free( data );
+		data = NULL;
+		if( length ){
+			*length = 0;
+		}
+	}
+
+	g_object_unref( file );
+
+	return( data );
+}
+
 /**
  * na_core_utils_print_version:
  *
