@@ -41,9 +41,13 @@
 NADataDef data_def_item [] = {
 
 	/* this data is marked as non readable as it has to be readen specifically
-	 * in order to be able to create the corresponding NAObjectItem-derived object
-	 * it is not writable as different I/O providers have different values for it
-	 * it is not instantiated
+	 * in order to be able to create the corresponding NAObjectItem-derived
+	 * object
+	 * it is not writable as different I/O providers may have different values
+	 * for it, and thus it must be written specifically
+	 * (cf. nagp_writer_write_start(), nadp_writer_write_start())
+	 * it is not instantiated because we never need to have an actual value
+	 * (actually being determined at runtime by object class)
 	 * it is just left here to be able to define the corresponding GConf schema
 	 * and to export it as XML
 	 */
@@ -62,6 +66,7 @@ NADataDef data_def_item [] = {
 				FALSE,
 				FALSE,
 				FALSE,
+				FALSE,
 				"type",
 				NULL,
 				0,
@@ -85,6 +90,7 @@ NADataDef data_def_item [] = {
 					"It is also used as a default for the toolbar label of an action." ),
 				NAFD_TYPE_LOCALE_STRING,
 				"",
+				FALSE,
 				TRUE,
 				TRUE,
 				FALSE,
@@ -108,6 +114,7 @@ NADataDef data_def_item [] = {
 					"with his/her mouse." ),
 				NAFD_TYPE_LOCALE_STRING,
 				"",
+				FALSE,
 				TRUE,
 				TRUE,
 				FALSE,
@@ -132,6 +139,7 @@ NADataDef data_def_item [] = {
 					"May be the localized name of a themed icon, or a full path to any appropriate image." ),
 				NAFD_TYPE_LOCALE_STRING,
 				"",
+				FALSE,
 				TRUE,
 				TRUE,
 				FALSE,
@@ -154,6 +162,7 @@ NADataDef data_def_item [] = {
 					"May be used, e.g. when displaying available items on a web site." ),
 				NAFD_TYPE_LOCALE_STRING,
 				"",
+				FALSE,
 				TRUE,
 				TRUE,
 				FALSE,
@@ -167,6 +176,33 @@ NADataDef data_def_item [] = {
 				NULL,
 				NULL },
 
+	{ NAFO_DATA_SHORTCUT,
+				TRUE,
+				TRUE,
+				TRUE,
+				N_( "Suggested shortcut" ),
+				N_( "A shortcut suggested for the action or the menu.\n" \
+					"Please note that this might be only a suggestion as the shortcut may " \
+					"be already reserved for another use. Implementation should not override " \
+					"an already existing shortcut to define this one.\n" \
+					"The format may look like \"<Control>a\" or \"<Shift><Alt>F1\".\n" \
+					"Defaults to empty." ),
+				NAFD_TYPE_STRING,
+				"",
+				FALSE,
+				TRUE,
+				TRUE,
+				FALSE,
+				FALSE,
+				"shortcut",
+				"SuggestedShortcut",
+				0,
+				NULL,
+				0,
+				0,
+				NULL,
+				NULL },
+
 	/* dynamic data, so not readable / not writable
 	 */
 	{ NAFO_DATA_SUBITEMS,
@@ -177,6 +213,7 @@ NADataDef data_def_item [] = {
 				"List of subitems objects",
 				NAFD_TYPE_POINTER,
 				NULL,
+				FALSE,
 				FALSE,			/* not copyable */
 				FALSE,			/* not comparable */
 				FALSE,			/* not mandatory */
@@ -208,6 +245,7 @@ NADataDef data_def_item [] = {
 				FALSE,
 				FALSE,
 				FALSE,
+				FALSE,
 				"items",
 				NULL,		/* Profiles or ItemsList */
 				0,
@@ -227,6 +265,7 @@ NADataDef data_def_item [] = {
 					"Defaults to TRUE." ),
 				NAFD_TYPE_BOOLEAN,
 				"true",
+				FALSE,
 				TRUE,
 				TRUE,
 				FALSE,
@@ -256,6 +295,7 @@ NADataDef data_def_item [] = {
 				"TRUE if an eccor occurs on a later write operation.",
 				NAFD_TYPE_BOOLEAN,
 				"false",
+				FALSE,
 				TRUE,
 				FALSE,
 				FALSE,
@@ -279,6 +319,7 @@ NADataDef data_def_item [] = {
 				"A pointer to the NAIOProvider object.",
 				NAFD_TYPE_POINTER,
 				NULL,
+				FALSE,
 				TRUE,
 				FALSE,
 				FALSE,
@@ -294,6 +335,8 @@ NADataDef data_def_item [] = {
 
 	/* dynamic data, so non readable / non writable (but has property)
 	 * is left at the NAIIOProvider disposition
+	 * not copyable as directly duplicated by NAIIOProvider interface
+	 * (see NAObjectItem::object_copy)
 	 */
 	{ NAFO_DATA_PROVIDER_DATA,
 				FALSE,
@@ -303,7 +346,8 @@ NADataDef data_def_item [] = {
 				"A pointer to some NAIOProvider specific data.",
 				NAFD_TYPE_POINTER,
 				NULL,
-				TRUE,
+				FALSE,
+				FALSE,
 				FALSE,
 				FALSE,
 				FALSE,
@@ -316,5 +360,35 @@ NADataDef data_def_item [] = {
 				NULL,
 				NULL },
 
+	/* this integer version number is introduced with .desktop files and obsoletes
+	 * the previous string version number which was only set on actions
+	 * we so have: "1.0" < "1.1" < "2.0" < 3
+	 * Also note that iversion=3 is only written in GConf, while .desktop files
+	 * do not have this key.
+	 * Only when version will need to be incremented again, we will write a version
+	 * key in .desktop files (probably 1 or 2), and increment this iversion to 4.
+	 */
+	{ NAFO_DATA_IVERSION,
+				TRUE,
+				TRUE,
+				TRUE,
+				N_( "Version of the format" ),
+				N_( "The version of the configuration format that will be used to manage backward compatibility." ),
+				NAFD_TYPE_UINT,
+				"3",
+				FALSE,
+				TRUE,
+				TRUE,
+				FALSE,
+				FALSE,
+				"iversion",
+				NULL,
+				0,
+				NULL,
+				0,
+				0,
+				NULL,
+				NULL },
+
 	{ NULL },
 };
