@@ -683,235 +683,3 @@ na_object_profile_new_with_defaults( void )
 
 	return( profile );
 }
-
-/**
- * Expands the parameters path, in function of the found tokens.
- *
- * @profile: the selected profile.
- * @target: the current target.
- * @files: the list of currently selected #NASelectedInfo items.
- *
- * Valid parameters are :
- *
- * %d : base dir of the (first) selected file(s)/folder(s)
- * %f : the name of the (first) selected file/folder
- * %h : hostname of the (first) URI
- * %m : list of the basename of the selected files/directories separated by space.
- * %M : list of the selected files/directories with their complete path separated by space.
- * %p : port number from the (first) URI
- * %R : space-separated list of URIs
- * %s : scheme of the (first) URI
- * %u : (first) URI
- * %U : username of the (first) URI
- * %% : a percent sign
- *
- * Adding a parameter requires updating of :
- * - nautilus-actions/core/na-object-profile.c::na_object_profile_parse_parameters()
- * - nautilus-actions/nact/nact-icommand-tab.c:parse_parameters()
- * - nautilus-actions/nact/nautilus-actions-config-tool.ui:LegendDialog
- */
-gchar *
-na_object_profile_parse_parameters( const NAObjectProfile *profile, gint target, GList* files )
-{
-	gchar *parsed = NULL;
-	GString *string;
-	GList *ifi;
-	gboolean first;
-	gchar *iuri, *ipath, *ibname;
-	GFile *iloc;
-	gchar *uri = NULL;
-	gchar *scheme = NULL;
-	gchar *dirname = NULL;
-	gchar *filename = NULL;
-	gchar *hostname = NULL;
-	gchar *username = NULL;
-	gint port_number = 0;
-	GString *basename_list, *pathname_list, *uris_list;
-	gchar *tmp, *iter, *old_iter;
-	NAGnomeVFSURI *vfs;
-
-	g_return_val_if_fail( NA_IS_OBJECT_PROFILE( profile ), NULL );
-
-	if( profile->private->dispose_has_run ){
-		return( NULL );
-	}
-
-	string = g_string_new( "" );
-	basename_list = g_string_new( "" );
-	pathname_list = g_string_new( "" );
-	uris_list = g_string_new( "" );
-	first = TRUE;
-
-	for( ifi = files ; ifi ; ifi = ifi->next ){
-
-		iuri = na_selected_info_get_uri( NA_SELECTED_INFO( ifi->data ));
-		iloc = na_selected_info_get_location( NA_SELECTED_INFO( ifi->data ));
-		ipath = g_file_get_path( iloc );
-		ibname = g_file_get_basename( iloc );
-
-		if( first ){
-
-			vfs = g_new0( NAGnomeVFSURI, 1 );
-			na_gnome_vfs_uri_parse( vfs, iuri );
-
-			uri = g_strdup( iuri );
-			dirname = ipath ? g_path_get_dirname( ipath ) : NULL;
-			scheme = g_strdup( vfs->scheme );
-			filename = g_strdup( ibname );
-			hostname = g_strdup( vfs->host_name );
-			username = g_strdup( vfs->user_name );
-			port_number = vfs->host_port;
-
-			first = FALSE;
-			na_gnome_vfs_uri_free( vfs );
-		}
-
-		if( ibname ){
-			if( strlen( basename_list->str )){
-				basename_list = g_string_append( basename_list, " " );
-			}
-			tmp = g_shell_quote( ibname );
-			g_string_append_printf( basename_list, "%s", tmp );
-			g_free( tmp );
-		}
-
-		if( ipath ){
-			if( strlen( pathname_list->str )){
-				pathname_list = g_string_append( pathname_list, " " );
-			}
-			tmp = g_shell_quote( ipath );
-			g_string_append_printf( pathname_list, "%s", tmp );
-			g_free( tmp );
-		}
-
-		if( strlen( uris_list->str )){
-			uris_list = g_string_append( uris_list, " " );
-		}
-		tmp = g_shell_quote( iuri );
-		g_string_append_printf( uris_list, "%s", tmp );
-		g_free( tmp );
-
-		g_free( ibname );
-		g_free( ipath );
-		g_object_unref( iloc );
-		g_free( iuri );
-	}
-
-	iter = na_object_get_parameters( profile );
-	old_iter = iter;
-
-	while(( iter = g_strstr_len( iter, strlen( iter ), "%" ))){
-
-		string = g_string_append_len( string, old_iter, strlen( old_iter ) - strlen( iter ));
-		switch( iter[1] ){
-
-			/* base dir of the (first) selected item
-			 */
-			case 'd':
-				if( dirname ){
-					tmp = g_shell_quote( dirname );
-					string = g_string_append( string, tmp );
-					g_free( tmp );
-				}
-				break;
-
-			/* basename of the (first) selected item
-			 */
-			case 'f':
-				if( filename ){
-					tmp = g_shell_quote( filename );
-					string = g_string_append( string, tmp );
-					g_free( tmp );
-				}
-				break;
-
-			/* hostname of the (first) URI
-			 */
-			case 'h':
-				if( hostname ){
-					string = g_string_append( string, hostname );
-				}
-				break;
-
-			/* space-separated list of the basenames
-			 */
-			case 'm':
-				if( basename_list->str ){
-					string = g_string_append( string, basename_list->str );
-				}
-				break;
-
-			/* space-separated list of full pathnames
-			 */
-			case 'M':
-				if( pathname_list->str ){
-					string = g_string_append( string, pathname_list->str );
-				}
-				break;
-
-			/* port number of the (first) URI
-			 */
-			case 'p':
-				if( port_number > 0 ){
-					g_string_append_printf( string, "%d", port_number );
-				}
-				break;
-
-			/* list of URIs
-			 */
-			case 'R':
-				if( uris_list->str ){
-					string = g_string_append( string, uris_list->str );
-				}
-				break;
-
-			/* scheme of the (first) URI
-			 */
-			case 's':
-				if( scheme ){
-					string = g_string_append( string, scheme );
-				}
-				break;
-
-			/* URI of the first item
-			 */
-			case 'u':
-				if( uri ){
-					string = g_string_append( string, uri );
-				}
-				break;
-
-			/* username of the (first) URI
-			 */
-			case 'U':
-				if( username ){
-					string = g_string_append( string, username );
-				}
-				break;
-
-			/* a percent sign
-			 */
-			case '%':
-				string = g_string_append_c( string, '%' );
-				break;
-		}
-
-		iter += 2;			/* skip the % sign and the character after */
-		old_iter = iter;	/* store the new start of the string */
-	}
-
-	string = g_string_append_len( string, old_iter, strlen( old_iter ));
-
-	g_free( uri );
-	g_free( dirname );
-	g_free( scheme );
-	g_free( hostname );
-	g_free( username );
-	g_free( iter );
-	g_string_free( uris_list, TRUE );
-	g_string_free( basename_list, TRUE );
-	g_string_free( pathname_list, TRUE );
-
-	parsed = g_string_free( string, FALSE );
-	return( parsed );
-}
